@@ -14,6 +14,8 @@
 # type: ignore
 from typing import Any
 
+import dsnparse
+
 from .keychain import get_default_keychain
 from .keychain import Keychain
 from .keyinspector import KeyInspector
@@ -32,6 +34,14 @@ __all__ = [
 ]
 
 
+def parse_dsn(dsn: str | dsnparse.ParseResult) -> KeySpecification:
+   """Parse a key specification from a Data Source Name (DSN)."""
+   if isinstance(dsn, str):
+      dsn = dsnparse.parse(dsn)
+   p = provider(dsn.scheme)
+   return p.parse_dsn(dsn)
+
+
 def parse_spec(spec: dict[str, Any]) -> KeySpecification:
     """Parse the specification of a *key* using the parameters defined by the
     specification `spec`.
