@@ -131,6 +131,15 @@ class Keychain(IKeychain):
             if isinstance(x, KeySpecification)
         })
 
+    def public(self) -> 'IKeychain':
+        """Return the :class:`Keychain` with only the keys that can perform
+        public operations.
+        """
+        return type(self)(keys={
+            x.kid: x for x in self._keys.values()
+            if isinstance(x, PublicKeySpecification)
+        })
+
     def tagged(self, tags: str | list[str] | set[str]) -> 'IKeychain':
         Impl = type(self)
         if isinstance(tags, str):
