@@ -14,6 +14,7 @@
 # limitations under the License.
 from typing import Any
 
+import pydantic
 from cryptography.hazmat.primitives.serialization import load_pem_public_key
 from google.cloud.kms import KeyManagementServiceAsyncClient
 
@@ -61,8 +62,8 @@ class GoogleKeySpecification(KeySpecification):
     use: KeyUseType | None
     project: str | None
     location: str
-    keyring: str
-    key: str
+    keyring: str = pydantic.Field(..., alias='key_ring')
+    key: str = pydantic.Field(..., alias='crypto_key')
     version: int
     public: CryptographyPublicKeyType | None
 
