@@ -11,9 +11,18 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from .timestamper import Timestamper
 from .timestampingauthority import TimestampingAuthority
 
 
 __all__: list[str] = [
+    'Timestamper',
     'TimestampingAuthority'
-]
\ No newline at end of file
+]
+
+
+def get_default_timestamper() -> Timestamper:
+    """Return the default :class:`Timestamper` instance
+    that is configured for an application.
+    """
+    return Timestamper.default()
\ No newline at end of file
